==> org-lsst-ccs-ui-1.5.1-sources.jar: org/lsst/ccs/gconsole/plugins/dictionary/AgentTable.java <==
package org.lsst.ccs.gconsole.plugins.dictionary;

import java.awt.Component;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.util.ArrayList;
import javax.swing.JCheckBox;
import javax.swing.JTable;
import javax.swing.ListSelectionModel;
import javax.swing.RowFilter;
import javax.swing.table.DefaultTableCellRenderer;
import javax.swing.table.TableRowSorter;
import org.lsst.ccs.bus.messages.AgentInfo;

/**
 *
 * @author emarin
 */
public class AgentTable extends JTable implements ItemListener {

    private static final Object[] columnNames = {"agentName"};
    private AgentDefaultTableModel tableModel = new AgentDefaultTableModel(columnNames, 0); 
    private TableRowSorter<AgentDefaultTableModel> sorter = new TableRowSorter<AgentDefaultTableModel>(tableModel); 
    private boolean[] checkSelected = new boolean[AgentInfo.AgentType.values().length]; 
    
    public AgentTable() {
        setModel(tableModel);
        setRowSorter(sorter);
        getColumn("agentName").setCellRenderer(new DefaultTableCellRenderer() {

            @Override
            public Component getTableCellRendererComponent(JTable table, Object value, boolean isSelected, boolean hasFocus, int row, int column) {
                super.getTableCellRendererComponent(table, value, isSelected, hasFocus, row, column);
                if (value != null){
                    setText(((AgentInfo)value).getName());
                    setToolTipText(((AgentInfo)value).getName());
                }
                return this;
            }
        }
        
        );
        getColumn("agentName").setPreferredWidth(200);
        setRowHeight(27);
        
        setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
//        setCellSelectionEnabled(true);
        this.setShowGrid(false);
        this.setTableHeader(null);
    }

    @Override
    public void itemStateChanged(ItemEvent e) {
        JCheckBox checkBox = (JCheckBox)e.getSource();
        String name = checkBox.getName();
        AgentInfo.AgentType type = AgentInfo.AgentType.valueOf(name);
        checkSelected[type.ordinal()]=checkBox.isSelected();

        // Create array of filters
        ArrayList<RowFilter<AgentDefaultTableModel,Integer>> filterList = new ArrayList<RowFilter<AgentDefaultTableModel,Integer>>();
    
        
        for (AgentInfo.AgentType agentType : AgentInfo.AgentType.values()){

                if (checkSelected[agentType.ordinal()]){
                    filterList.add(new RowFilter<AgentDefaultTableModel,Integer>(){
                        
                        @Override
                        public boolean include(RowFilter.Entry<? extends AgentDefaultTableModel, ? extends Integer> entry) {
                            AgentInfo agent = (AgentInfo)entry.getModel().getValueAt(entry.getIdentifier(), 0);
                            if (agent.getType().equals(agentType)){
                                return true;
                            }
                            else return false;
                        }
                        
                    });
                }
        }
        
        // update Filter
        RowFilter filter;
        filter = RowFilter.orFilter(filterList);
        sorter.setRowFilter(filter);
    }

}

==> org-lsst-ccs-ui-2.3.6-sources.jar: org/lsst/ccs/gconsole/plugins/dictionary/AgentTable.java <==
package org.lsst.ccs.gconsole.plugins.dictionary;

import java.awt.Component;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.util.ArrayList;
import javax.swing.JCheckBox;
import javax.swing.JTable;
import javax.swing.ListSelectionModel;
import javax.swing.RowFilter;
import javax.swing.table.DefaultTableCellRenderer;
import javax.swing.table.TableRowSorter;
import org.lsst.ccs.bus.data.AgentInfo;

/**
 *
 * @author emarin
 */
public class AgentTable extends JTable implements ItemListener {

    private static final Object[] columnNames = {"agentName"};
    private AgentDefaultTableModel tableModel = new AgentDefaultTableModel(columnNames, 0); 
    private TableRowSorter<AgentDefaultTableModel> sorter = new TableRowSorter<AgentDefaultTableModel>(tableModel); 
    private boolean[] checkSelected = new boolean[AgentInfo.AgentType.values().length]; 
    
    public AgentTable() {
        setModel(tableModel);
        setRowSorter(sorter);
        getColumn("agentName").setCellRenderer(new DefaultTableCellRenderer() {

            @Override
            public Component getTableCellRendererComponent(JTable table, Object value, boolean isSelected, boolean hasFocus, int row, int column) {
                super.getTableCellRendererComponent(table, value, isSelected, hasFocus, row, column);
                if (value != null){
                    setText(((AgentInfo)value).getName());
                    setToolTipText(((AgentInfo)value).getName());
                }
                return this;
            }
        }
        
        );
        getColumn("agentName").setPreferredWidth(200);
        setRowHeight(27);
        
        setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
//        setCellSelectionEnabled(true);
        this.setShowGrid(false);
        this.setTableHeader(null);
    }

    @Override
    public void itemStateChanged(ItemEvent e) {
        JCheckBox checkBox = (JCheckBox)e.getSource();
        String name = checkBox.getName();
        AgentInfo.AgentType type = AgentInfo.AgentType.valueOf(name);
        checkSelected[type.ordinal()]=checkBox.isSelected();

        // Create array of filters
        ArrayList<RowFilter<AgentDefaultTableModel,Integer>> filterList = new ArrayList<RowFilter<AgentDefaultTableModel,Integer>>();
    
        
        for (AgentInfo.AgentType agentType : AgentInfo.AgentType.values()){

                if (checkSelected[agentType.ordinal()]){
                    filterList.add(new RowFilter<AgentDefaultTableModel,Integer>(){
                        
                        @Override
                        public boolean include(RowFilter.Entry<? extends AgentDefaultTableModel, ? extends Integer> entry) {
                            AgentInfo agent = (AgentInfo)entry.getModel().getValueAt(entry.getIdentifier(), 0);
                            if (agent.getType().equals(agentType)){
                                return true;
                            }
                            else return false;
                        }
                        
                    });
                }
        }
        
        // update Filter
        RowFilter filter;
        filter = RowFilter.orFilter(filterList);
        sorter.setRowFilter(filter);
    }

}
